@@ -569,7 +569,7 @@ class DAQ6510Proxy(Proxy, DAQ6510Interface):
         protocol: str = CTRL_SETTINGS.PROTOCOL,
         hostname: str = CTRL_SETTINGS.HOSTNAME,
         port: int = CTRL_SETTINGS.COMMANDING_PORT,
-        timeout: int = CTRL_SETTINGS.TIMEOUT * 1000,  # Timeout [ms]: > scan count * interval + (one scan duration)
+        timeout: float = CTRL_SETTINGS.TIMEOUT,  # Timeout [s]: > scan count * interval + (one scan duration)
     ):
         """Initialisation of a DAQ6510Proxy.
 
@@ -578,7 +578,7 @@ class DAQ6510Proxy(Proxy, DAQ6510Interface):
             hostname (str): Location of the Control Server (IP address) [default is taken from settings file]
             port (int): TCP port on which the Control Server is listening for commands [default is taken from settings
                         file]
-            timeout (int): Timeout by which to establish the connection [ms]
+            timeout (float): Timeout by which to establish the connection [s]
         """
 
         super().__init__(connect_address(protocol, hostname, port), timeout=timeout)
